@@ -353,8 +353,8 @@ class tx_felogin_pi1 extends tslib_pibase {
 		$isFeloginBaseURL = !empty($this->conf['feloginBaseURL']);
 
 		$link = $this->pi_getPageLink($GLOBALS['TSFE']->id, '', array(
-			$this->prefixId . '[user]' => $user['uid'],
-			$this->prefixId . '[forgothash]' => $randHash
+			rawurlencode($this->prefixId . '[user]') => $user['uid'],
+			rawurlencode($this->prefixId . '[forgothash]') => $randHash
 		));
 
 			// Prefix link if necessary
@@ -984,4 +984,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/felogin/pi1/class.tx_felogin_pi1.php']);
 }
 
-?>
\ No newline at end of file
+?>
